
*Here are some examples of making a map in Stata. As with any language, there are multiple ways we could write these commands and produce these maps. And there are many ways to make a map look nice. To make a map look really nice, we need to play around with it and try out different features.

*Set the "CD", the current directory. This tells Stata where to save your files when converting the shapefile to regular data. 
cd "/Users/ayala.wineman/Documents/MwAPATA/Aquaculture"

*Select the shapefile that you will use and copy the path below. MWI_adm1 is the district-level shapefile we want. (MWI_adm3 seems to be Traditional Authorities.)
global shapefile "/Users/ayala.wineman/Documents/Malawi LSMS/Malawi Shapefiles/MWI_adm1.shp"

*Specify the data that you want to map. This should have districts (names or codes) that can be merged into the shapefile. Both files need to share the same district names or codes.
global fish_farm_data "/Users/ayala.wineman/Documents/MwAPATA/Aquaculture/Fish farms in Malawi - 2017.xlsx"

*Install spmap and shp2dta on your computer. You only need to do this once.
ssc install spmap
ssc install shp2dta

*Convert shapefile to data in a format that Stata can understand. We'll call the data file "malawi_districts". We also need to specify a name for the data file containing the coordinates of the districts ("malawi_districts_coordinates").
shp2dta using "${shapefile}", database(malawi_districts) coordinates(malawi_districts_coordinates) genid(newid) gencentroids(centroid) replace 

*Try opening the database you just created. There should be 28 rows with 28 districts. The variable that contains the district names is called "NAME_1".
use "malawi_districts.dta", clear
describe

*Start by creating a blank map of Malawi's districts. The ID for each polygon is a variable called "_ID". We can make the outline of the map black and the width of the lines very thin (vthin).
spmap using "malawi_districts_coordinates.dta", id(ID_1) ocolor(black) osize(vthin)

*Import the data on fish farms from Excel into Stata and save as a Stata data file.
import excel "${fish_farm_data}", sheet("Sheet1") firstrow clear
save "fish_farm_data.dta", replace // Note that this automatically is saved to the current directory. 

*Merge in the data that you will be mapping. 
use "malawi_districts.dta", clear
rename NAME_1 district
merge 1:1 district using "fish_farm_data.dta", nogen keep (1 3)

*Make a choropleth map with the number of fish farmers in each district. We'll use shades of green and categorize districts into bins of 0-200 farms, 200-400 farms, etc.
spmap fish_farmers using "malawi_districts_coordinates.dta", id(ID_1) clmethod(custom) clbreaks(0 200 400 600 800 1000 1200) fcolor(Greens)

*Make a map with the number of fish farms (not farmers). This time, use the color scheme called "Blues".
spmap fish_farms using "malawi_districts_coordinates.dta", id(ID_1) clmethod(custom) clbreaks(0 200 400 600 800 1000) fcolor(Blues) 

*Make a map with the bins determined automatically in Stata. This time, use the color scheme called "Heat".
spmap fish_farms using "malawi_districts_coordinates.dta", id(ID_1) clmethod(quantile) clnumber(5) fcolor(Blues) 

*Make a map with circles overlaid on the districts (in the center, using the centroid coordinates) that convey the number of fish farms in each district.
spmap using malawi_districts_coordinates, id(ID_1) fcolor(eggshell) point(x(x_centroid) y(y_centroid) proportional(fish_farms) fcolor(orange) size(3)) ocolor(black) label(x(x_centroid) y(y_centroid) label(fish_farms) color(black) size(3)) title("Number of fish farms")

*Identify the 10 districts in your aquaculture survey.
gen districts_10 = 1 if inlist(district, "Nkhata Bay", "Mzimba", "Ntchisi", "Nkhotakota", "Mchinji")
replace districts_10 = 1 if inlist(district,"Phalombe", "Thyolo", "Mulanje", "Machinga", "Zomba")
replace districts_10 = 0 if districts_10==.

*Make a map with the 10 districts. 
spmap districts_10 using "malawi_districts_coordinates.dta", id(ID_1) clmethod(unique) 




*You can adjust the colors either in the syntax (writing the command in your do-file) or manually in "graph editor". You can give the map a title, label your legend, remove your legend, label your districts, etc. Some details can be found at http://repec.org/bocode/s/spmap or by typing "help spmap" into Stata. There are also other online resources like YouTube videos, etc.
